import 'package:flutter/material.dart';
import 'package:og1_system/og1_system.dart';
import 'package:og1_ui/src/models/_models.dart';

enum SupportedCommoditiesEnum {
  all(1),
  water(2),
  food(3),
  clothing(4),
  housing(5);

  final int value;

  const SupportedCommoditiesEnum(this.value);

  CommodityModel commodityModel(List<CommodityModel> supportedCommodities) =>
      supportedCommodities.firstWhere((commModel) => commModel.id == value);
}

class SupportedCommodities {
  late List<CommodityModel> supportedCommodities;

  SupportedCommodities({this.supportedCommodities = _supportedCommodities});

  SupportedCommodities.fromEnums(
      List<SupportedCommoditiesEnum> supportedCommoditiesEnum) {
    supportedCommodities = supportedCommoditiesEnum
        .map((commEnum) => commEnum.commodityModel(_supportedCommodities))
        .toList();
  }

  SupportedCommoditiesEnum supportedCommoditiesEnum(CommodityModel comm) {
    return SupportedCommoditiesEnum.values
        .firstWhere((commEnum) => commEnum.value == comm.id);
  }

  static const List<CommodityModel> _supportedCommodities = <CommodityModel>[
    CommodityModel(1, "All", FontAwesomeIcons.ribbon, Colors.deepPurple),
    CommodityModel(2, "Water", Icons.water_drop_outlined, Colors.blue),
    CommodityModel(3, "Food", FontAwesomeIcons.pizzaSlice, Colors.deepOrange),
    CommodityModel(4, "Clothing", FontAwesomeIcons.tshirt, Colors.indigo),
    CommodityModel(5, "Housing", Icons.house_outlined, Colors.amber),
  ];

  static SupportedCommodities get commodities =>
      SupportedCommodities.fromEnums([
        SupportedCommoditiesEnum.all,
        SupportedCommoditiesEnum.water,
        SupportedCommoditiesEnum.food,
        SupportedCommoditiesEnum.clothing,
        SupportedCommoditiesEnum.housing,
      ]);
}
