import 'package:flutter/material.dart';
import 'package:og1_ui/src/models/_models.dart';

enum SupportedLanguagesEnum {
  enUS(1),
  mkMK(2);

  final int value;

  const SupportedLanguagesEnum(this.value);

  LanguageModel languageModel(List<LanguageModel> supportedLanguages) =>
      supportedLanguages.firstWhere((langModel) => langModel.id == value);
}

class SupportedLanguages {
  late List<LanguageModel> supportedLanguages;

  SupportedLanguages({this.supportedLanguages = _supportedLanguages});

  SupportedLanguages.fromEnums(
      List<SupportedLanguagesEnum> supportedLanguagesEnum) {
    supportedLanguages = supportedLanguagesEnum
        .map((langEnum) => langEnum.languageModel(_supportedLanguages))
        .toList();
  }

  List<Locale> get locales =>
      supportedLanguages.map((lang) => lang.locale).toList();

  SupportedLanguagesEnum supportedLanguagesEnum(LanguageModel lang) {
    return SupportedLanguagesEnum.values
        .firstWhere((langEnum) => langEnum.value == lang.id);
  }

  static const List<LanguageModel> _supportedLanguages = <LanguageModel>[
    LanguageModel(1, "🇺🇸", "English", "en", "US"),
    LanguageModel(2, "🇲🇰", "Македонски", "mk", "MK"),
  ];

  static SupportedLanguages get languages => SupportedLanguages.fromEnums([
        SupportedLanguagesEnum.enUS,
        SupportedLanguagesEnum.mkMK,
      ]);
}
