import 'package:flutter/material.dart';
import 'package:og1_system/og1_system.dart';
import 'package:og1_ui/og1_ui.dart';

class LanguageService {
  final List<LanguageModel> supportedLanguages;

  const LanguageService(this.supportedLanguages);

  void setupLanguage(BuildContext context) async {
    changeAppLanguage(context, context.locale);
  }

  Future<LanguageModel> get selectedLanguage async {
    return getLanguage(await SharePreferenceService.getValue<String>(
        SharePreferenceKey.selectedLanguage));
  }

  Future<Locale?> get selectedLocale async {
    return getLocale(await SharePreferenceService.getValue<String>(
        SharePreferenceKey.selectedLanguage));
  }

  Future<void> changeAppLanguage(BuildContext context, Locale locale) async {
    if (await selectedLocale != locale) {
      await context.setLocale(locale);
      await SharePreferenceService.setValue(
          SharePreferenceKey.selectedLanguage, locale.toString());
    }
  }

  Locale? getLocale(String? locale) {
    if (locale != null) {
      List<String> localeList = locale.split('_');
      if (localeList.length == 2) {
        return Locale(localeList[0], localeList[1]);
      }
    }
    return null;
  }

  LanguageModel getLanguage(String? locale) {
    if (locale != null) {
      List<String> localeList = locale.split('_');
      if (localeList.length == 2) {
        return supportedLanguages.firstWhere(
            (lang) =>
                lang.languageCode == localeList[0] &&
                lang.countryName == localeList[1],
            orElse: () => supportedLanguages.first);
      }
    }
    return supportedLanguages.first;
  }
}
