import 'package:flutter/material.dart';
import 'package:og1_system/og1_system.dart';

class Og1IconLauncher extends StatelessWidget {
  final double? width;
  final double? height;
  final double? iconWidth;
  final double? iconHeight;
  final String? icon;
  final String url;
  final Icon? placeholderIcon;
  final Text? placeholderText;
  final Function()? onTap;

  const Og1IconLauncher({
    super.key,
    this.width,
    this.height,
    this.iconWidth,
    this.iconHeight,
    this.icon,
    required this.url,
    this.placeholderIcon,
    this.placeholderText,
    this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: GestureDetector(
        onTap: onTap ?? () => _launchInApp(url),
        child: ClipRRect(
          borderRadius: BorderRadius.circular(8.0),
          child: ImageFade(
            image: icon != null ? _image(icon!) : null,
            duration: const Duration(milliseconds: 900),
            syncDuration: const Duration(milliseconds: 150),
            width: iconWidth,
            height: iconHeight,
            fit: BoxFit.scaleDown,
            alignment: FractionalOffset.center,
            repeat: ImageRepeat.noRepeat,
            errorBuilder: (context, error) => Container(
              alignment: FractionalOffset.center,
              child: const Icon(Icons.broken_image_outlined),
            ),
            placeholder: (placeholderIcon != null || placeholderText != null)
                ? Container(
                    alignment: FractionalOffset.center,
                    child: placeholderIcon ?? placeholderText,
                  )
                : null,
          ),
        ),
      ),
    );
  }

  T _image<T extends ImageProvider<Object>>(String icon) {
    return icon.contains('http')
        ? NetworkImage(icon) as T
        : AssetImage(icon) as T;
  }

  Future<void> _launchInApp(String url) async {
    if (await canLaunch(url)) {
      await launch(
        url,
        forceSafariVC: true,
        forceWebView: true,
        enableJavaScript: true,
        enableDomStorage: true,
        headers: <String, String>{'my_header_key': 'my_header_value'},
      );
    } else {
      throw 'Could not launch $url';
    }
  }
}
